@@ -5,14 +5,14 @@ test_that("PCA fairness and plot", {
 
   f_pca <- fairness_pca(fobject)
   data_c <- data[ , apply(data, 2, function(x) !any(is.na(x)))]
-  data_c <- data_c[, colnames(data_c) %in% unique_metrics()]
+  data_c <- data_c[, colnames(data_c) %in% parity_loss_metrics()]
   true_pca <- stats::prcomp(data_c, scale = TRUE)
 
   expect_equal(f_pca$x, true_pca$x)
 
   f_pca2 <- fairness_pca(fobject, omit_models_with_NA = TRUE)
   data_r <- data[apply(data, 1, function(x) !any(is.na(x))), ]
-  data_r <- data_r[, colnames(data_r) %in% unique_metrics()]
+  data_r <- data_r[, colnames(data_r) %in% parity_loss_metrics()]
   true_pca2 <- stats::prcomp(data_r, scale = TRUE)
   a <- as.data.frame(true_pca2$x)
   b <- as.data.frame(f_pca2$x)
